# Statuscast API Package

This is a package for Automating API requests against [CofC StatusCast](https://cofc.statuscast.com/api/v1). 

## Requirements from Status Cast 2/11 Requirements Meeting
* Subscribe people by default
* Not going to monitor processes
* Getting subscribers in the program
* Faculty and staff - adding is not difficult, removing would be the challenge
* Faculty only applications we wouldn't modify students on (cognos)
* Initiate from EAM, then to helpdesk - send mail list to IT-SSCOM with a custom message
* Stackstorm scheduler

